summaryrefslogtreecommitdiffstats
path: root/library/cpp/xml/document/xml-document-decl.h
diff options
context:
space:
mode:
Diffstat (limited to 'library/cpp/xml/document/xml-document-decl.h')
-rw-r--r--library/cpp/xml/document/xml-document-decl.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/library/cpp/xml/document/xml-document-decl.h b/library/cpp/xml/document/xml-document-decl.h
index 643ba664680..552304bb520 100644
--- a/library/cpp/xml/document/xml-document-decl.h
+++ b/library/cpp/xml/document/xml-document-decl.h
@@ -29,10 +29,11 @@ namespace NXml {
/**
* create TDocument
* @param source: filename, XML string, or name for the root element (depends on @src)
* @param src: source type: File | String | RootName
* throws if file not found or cannot be parsed
*/
- TDocument(const TString& source, Source type = File);
+ TDocument(const TString& source, Source type = File, int parseOptions = XML_PARSE_NOCDATA);
public:
TDocument(const TDocument& that) = delete;
@@ -71,8 +72,8 @@ namespace NXml {
}
private:
- void ParseFile(const TString& file);
- void ParseString(TZtStringBuf xml);
+ void ParseFile(const TString& file, int parseOptions);
+ void ParseString(TZtStringBuf xml, int parseOptions);
TDocument(TDocHolder doc)
: Doc(std::move(doc))
@@ -29,10 +29,11 @@ namespace NXml {
* create TDocument
* @param source: filename, XML string, or name for the root element (depends on @src)
- * @param src: source type: File | String | RootName
+ * @param type: source type: File | String | RootName
+ * @param parseOptions: XML parser options
* throws if file not found or cannot be parsed
*/